pub struct CredentialPropertiesOutput {
pub discoverable: Option<bool>,
}Expand description
This client registration extension facilitates reporting certain credential properties known by
the client to the requesting WebAuthn Relying Party upon creation of a PublicKeyCredential
source as a result of a registration ceremony.
https://w3c.github.io/webauthn/#sctn-authenticator-credential-properties-extension
Fields
discoverable: Option<bool>This OPTIONAL property, known abstractly as the resident key credential property
(i.e., client-side discoverable credential property), is a Boolean value indicating whether
the PublicKeyCredential returned as a result of a registration ceremony is a client-side
discoverable credential.
- If
rkis true, the credential is a discoverable credential. - If
rkis false, the credential is a server-side credential. - If
rkis not present, it is not known whether the credential is a discoverable credential or a server-side credential.