pub struct WellKnown {
pub origins: Vec<Url>,
}Expand description
The payload hosted by a relying party to augment their WebAuthn experience.
Fields
origins: Vec<Url>Should the relying party wish to re-use an rpId accross multiple origin domains that otherwise would not pass validation for a webauthn ceremony.
To learn more please see refer to WebAuthn level 3 - 5.11 Using Web Authentication across related origins