AuthenticatedPublicKeyCredential

Type Alias AuthenticatedPublicKeyCredential 

pub type AuthenticatedPublicKeyCredential = PublicKeyCredential<AuthenticatorAssertionResponse>;
The response to the successful authentication of a PublicKeyCredential

Aliased Type

pub struct AuthenticatedPublicKeyCredential {
    pub id: String,
    pub raw_id: Bytes,
    pub ty: PublicKeyCredentialType,
    pub response: AuthenticatorAssertionResponse,
    pub authenticator_attachment: Option<AuthenticatorAttachment>,
    pub client_extension_results: AuthenticationExtensionsClientOutputs,
}

Fields

id: String

The id contains the credential ID, chosen by the authenticator. This is usually the base64url encoded data of Self::raw_id

The credential ID is used to look up credentials for use and is therefore expected to be globally unique with high probability across all credentials of the same type across all authenticators.

NOTE: This API does not constrain the format or length of this identifier, except that it MUST be sufficient for the authenticator to uniquely select a key.

raw_id: Bytes

The raw byte containing the credential ID, see Self::id for more information.

ty: PublicKeyCredentialTyperesponse: AuthenticatorAssertionResponse

This contains the authenticator’s response to the client’s request to either:

authenticator_attachment: Option<AuthenticatorAttachment>

This reports the modality of the communication between the client and authenticator.

client_extension_results: AuthenticationExtensionsClientOutputs

This object is a map containing extension identifier → client extension output entries produced by the extension’s client extension processing.